@@ -4,6 +4,7 @@ from django.db.models import AutoField
 from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
 
+from mezzanine.conf import settings
 from mezzanine.core.forms import DynamicInlineAdminForm
 from mezzanine.core.models import Orderable
 from mezzanine.utils.urls import content_media_urls, admin_url
@@ -13,7 +14,7 @@ from mezzanine.utils.urls import content_media_urls, admin_url
 # earlier versions of the admin.
 from django import VERSION
 displayable_js = []
-if VERSION > (1, 1, 0):
+if VERSION >= (1, 2, 0):
     displayable_js = content_media_urls("js/collapse_backport.js")
 
 
@@ -40,7 +41,7 @@ class DisplayableAdmin(admin.ModelAdmin):
     )
 
 
-class DynamicInlineAdmin(admin.TabularInline):
+class BaseDynamicInlineAdmin(object):
     """
     Admin inline that uses JS to inject an "Add another" link which
     when clicked, dynamically reveals another fieldset. Also handles
@@ -50,10 +51,9 @@ class DynamicInlineAdmin(admin.TabularInline):
 
     form = DynamicInlineAdminForm
     extra = 20
-    template = "admin/includes/dynamic_inline.html"
 
     def __init__(self, *args, **kwargs):
-        super(DynamicInlineAdmin, self).__init__(*args, **kwargs)
+        super(BaseDynamicInlineAdmin, self).__init__(*args, **kwargs)
         if issubclass(self.model, Orderable):
             fields = self.fields
             if not fields:
@@ -66,6 +66,25 @@ class DynamicInlineAdmin(admin.TabularInline):
                 fields.append("_order")
             self.fields = fields
 
+class TabularDynamicInlineAdmin(BaseDynamicInlineAdmin, admin.TabularInline):
+    template = "admin/includes/dynamic_inline_tabular.html"
+
+class StackedDynamicInlineAdmin(BaseDynamicInlineAdmin, admin.StackedInline):
+    template = "admin/includes/dynamic_inline_stacked.html"
+
+    def __init__(self, *args, **kwargs):
+        """
+        Stacked dynamic inlines won't work without grappelli
+        installed, as the JavaScript in dynamic_inline.js isn't
+        able to target each of the inlines to set the value of
+        the order field.
+        """
+        grappelli_name = getattr(settings, "PACKAGE_NAME_GRAPPELLI")
+        if grappelli_name not in settings.INSTALLED_APPS:
+            error = "StackedDynamicInlineAdmin requires Grappelli installed."
+            raise Exception(error)
+        super(StackedDynamicInlineAdmin, self).__init__(*args, **kwargs)
+
 
 class OwnableAdmin(admin.ModelAdmin):
     """
